@@ -2,7 +2,9 @@ from typing import List, Optional
 
 from camel_model.camel_model import CamelModel
 
+from domain.distribution.data_block import DataBlock
+
 
 class DistributionData(CamelModel):
-    distribution_title: Optional[str]
-    distribution_text: List[str] = []
+    subtitle: Optional[str]
+    blocks: List[DataBlock] = []
