@@ -7,9 +7,11 @@ from openpyxl.worksheet.worksheet import Worksheet
 from openpyxl_image_loader import SheetImageLoader
 from openpyxl.drawing.image import Image
 
+from domain.distribution.data_block import DataBlock
+from domain.distribution.distribution_image import DistributionImage
 from xlsx_lib.domain.distribution.distribution_cell_value_types import DistributionCellValueType
 from xlsx_lib.domain.distribution.distribution_data import DistributionData
-from xlsx_lib.domain.distribution.distribution_image import DistributionImage
+from xlsx_lib.domain.distribution.new_distribution_image import NewDistributionImage
 from xlsx_lib.domain.xlsx_elements.exceptions.continue_exception import ContinueException
 from xlsx_lib.domain.xlsx_elements.exceptions.sheet_end_exception import SheetEndException
 from xlsx_lib.domain.xlsx_elements.sheet import Sheet
@@ -23,7 +25,7 @@ def get_distribution_value_type(cell: Cell) -> DistributionCellValueType:
 
 
 class DistributionSheet(Sheet):
-    distribution_images: List[DistributionImage] = []
+    new_distribution_images: List[NewDistributionImage] = []
     max_col: int = 3
     start_col: int
 
@@ -44,20 +46,25 @@ class DistributionSheet(Sheet):
 
         image_loader = SheetImageLoader(worksheet)
 
-        image_index: int = 0
         for image in worksheet._images:
-            self.distribution_images.append(
-                DistributionImage(
-                    name=str(uuid.uuid4()),
-                    format=image.format,
+            file_name: str = f"{uuid.uuid4()}.{image.format}"
+
+            self.new_distribution_images.append(
+                NewDistributionImage(
+                    file_name=file_name,
                     file=image.ref,
-                    width=image.width,
-                    height=image.height,
-                    orderIndex=image_index
                 )
             )
 
-            image_index += 1
+            self.distribution_data.blocks.append(
+                DataBlock(
+                    image=DistributionImage(
+                        file_name=file_name,
+                        width=image.width,
+                        height=image.height,
+                    )
+                )
+            )
 
         self.process_sheet_data()
 
@@ -91,14 +98,16 @@ class DistributionSheet(Sheet):
         cell_value_type = get_distribution_value_type(cell)
 
         if cell_value_type is DistributionCellValueType.TEXT:
-            self.distribution_data.distribution_text.append(
-                self.sheet_reader.read_cell(
-                    row=row_index,
-                    col=col_index,
-                ).value
+            self.distribution_data.blocks.append(
+                DataBlock(
+                    text=[self.sheet_reader.read_cell(
+                        row=row_index,
+                        col=col_index,
+                    ).value],
+                )
             )
         elif cell_value_type is DistributionCellValueType.TITLE:
-            self.distribution_data.distribution_title = self.sheet_reader.read_cell(
+            self.distribution_data.subtitle = self.sheet_reader.read_cell(
                 row=row_index,
                 col=col_index,
             ).value
