@@ -6,8 +6,8 @@ from openpyxl import \
     load_workbook
 
 from xlsx_lib.domain.distribution.distribution_data import DistributionData
-from xlsx_lib.domain.distribution.distribution_image import DistributionImage
-from xlsx_lib.domain.distribution.distribution_sheet import DistributionSheet
+from xlsx_lib.domain.distribution.new_distribution_image import NewDistributionImage
+from xlsx_lib.domain.distribution.distribution_sheet import DistributionData, DistributionSheet
 from xlsx_lib.domain.power_supply.power_supply_component import PowerSupplyComponent
 from xlsx_lib.domain.power_supply.power_supply_sheet import PowerSupplySheet
 from xlsx_lib.domain.frame.frame_element import FrameElement
@@ -40,7 +40,7 @@ sheetnames_relationships = {
 
 class MotorcycleModelWorkbook:
     motorcycle_model: Optional[MotorcycleModel]
-    distribution_images: Optional[List[DistributionImage]]
+    new_distribution_images: Optional[List[NewDistributionImage]]
 
     def __init__(
             self,
@@ -91,7 +91,7 @@ class MotorcycleModelWorkbook:
                 distribution_sheet: DistributionSheet = DistributionSheet(worksheet=workbook[sheetname])
 
                 distribution = distribution_sheet.distribution_data
-                self.distribution_images = distribution_sheet.distribution_images
+                self.new_distribution_images = distribution_sheet.new_distribution_images
 
         self.motorcycle_model = MotorcycleModel(
             model_name=model_name,
